@@ -1,8 +1,7 @@
-
 from jupyterlab_server.test_utils import validate_request
 
 
 async def test_get_listing(jp_fetch, labserverapp):
     url = r"lab/api/listings/@jupyterlab/extensionmanager-extension/listings.json"
-    r = await jp_fetch(*url.split('/'))
+    r = await jp_fetch(*url.split("/"))
     validate_request(r)
